DeclEngine

Struct DeclEngine 

pub struct DeclEngine { /* private fields */ }
Used inside of type inference to store declarations.

Implementations

Source

impl DeclEngine

pub fn clear_program(&mut self, program_id: &ProgramId)

Source

impl DeclEngine

pub fn clear_module(&mut self, source_id: &SourceId)

Source

impl DeclEngine

pub fn insert_dummy_func( &self, decl: TyFunctionDecl, ) -> DeclRef<DeclId<TyFunctionDecl>>

Inserts a trait-interface dummy function into the DeclEngine.

This is a bit of a maverick compared to the regular DeclEngineInsert::insert. It deliberately inserts a ty::TyFunctionDecl without an associated parsed declaration.

Dummy functions are placeholders created from trait interface methods (see ty::TyTraitFn::to_dummy_func). They allow the trait’s provided methods to refer to interface methods before an actual implementation exists. Their parsed origin is a TraitFn (i.e., a parsed trait function), not a FunctionDeclaration, so there is no FunctionDeclaration to associate them with.

This is the only semantically valid case of a ty::TyFunctionDecl having no corresponding parsed declaration. Everything else must go through DeclEngineInsert::insert or DeclEngineInsert::insert_modified, which guarantee (and, for insert_modified, assert) the presence of a parsed declaration.

Panics if the decl is not a trait-interface dummy function.

pub fn get_function<I>(&self, index: &I) -> Arc<TyFunctionDecl>

Friendly helper method for calling the get method from the implementation of DeclEngineGet for DeclEngine

Calling [DeclEngine][get] directly is equivalent to this method, but this method adds additional syntax that some users may find helpful.

pub fn get_trait<I>(&self, index: &I) -> Arc<TyTraitDecl>

Friendly helper method for calling the get method from the implementation of DeclEngineGet for DeclEngine

Calling [DeclEngine][get] directly is equivalent to this method, but this method adds additional syntax that some users may find helpful.

pub fn get_traits_by_name(&self, trait_name: &Ident) -> Vec<TyTraitDecl>

Returns all the ty::TyTraitDecls whose name is the same as trait_name.

The method does a linear search over all the declared traits and is meant to be used only for diagnostic purposes.

pub fn get_trait_fn<I>(&self, index: &I) -> Arc<TyTraitFn>

Friendly helper method for calling the get method from the implementation of DeclEngineGet for DeclEngine

Calling [DeclEngine][get] directly is equivalent to this method, but this method adds additional syntax that some users may find helpful.

pub fn get_impl_self_or_trait<I>(&self, index: &I) -> Arc<TyImplSelfOrTrait>

Friendly helper method for calling the get method from the implementation of DeclEngineGet for DeclEngine

Calling [DeclEngine][get] directly is equivalent to this method, but this method adds additional syntax that some users may find helpful.

pub fn get_struct<I>(&self, index: &I) -> Arc<TyStructDecl>

Friendly helper method for calling the get method from the implementation of DeclEngineGet for DeclEngine

Calling [DeclEngine][get] directly is equivalent to this method, but this method adds additional syntax that some users may find helpful.

pub fn get_storage<I>(&self, index: &I) -> Arc<TyStorageDecl>

Friendly helper method for calling the get method from the implementation of DeclEngineGet for DeclEngine.

Calling [DeclEngine][get] directly is equivalent to this method, but this method adds additional syntax that some users may find helpful.

pub fn get_abi<I>(&self, index: &I) -> Arc<TyAbiDecl>

Friendly helper method for calling the get method from the implementation of DeclEngineGet for DeclEngine

Calling [DeclEngine][get] directly is equivalent to this method, but this method adds additional syntax that some users may find helpful.

pub fn get_constant<I>(&self, index: &I) -> Arc<TyConstantDecl>

Friendly helper method for calling the get method from the implementation of DeclEngineGet for DeclEngine

Calling [DeclEngine][get] directly is equivalent to this method, but this method adds additional syntax that some users may find helpful.

pub fn get_configurable<I>(&self, index: &I) -> Arc<TyConfigurableDecl>

Friendly helper method for calling the get method from the implementation of DeclEngineGet for DeclEngine

Calling [DeclEngine][get] directly is equivalent to this method, but this method adds additional syntax that some users may find helpful.

pub fn get_const_generic<I>(&self, index: &I) -> Arc<TyConstGenericDecl>

Friendly helper method for calling the get method from the implementation of DeclEngineGet for DeclEngine

Calling [DeclEngine][get] directly is equivalent to this method, but this method adds additional syntax that some users may find helpful.

pub fn get_type<I>(&self, index: &I) -> Arc<TyTraitType>

Friendly helper method for calling the get method from the implementation of DeclEngineGet for DeclEngine

Calling [DeclEngine][get] directly is equivalent to this method, but this method adds additional syntax that some users may find helpful.

pub fn get_enum<I>(&self, index: &I) -> Arc<TyEnumDecl>

Friendly helper method for calling the get method from the implementation of DeclEngineGet for DeclEngine

Calling [DeclEngine][get] directly is equivalent to this method, but this method adds additional syntax that some users may find helpful.

pub fn get_type_alias<I>(&self, index: &I) -> Arc<TyTypeAliasDecl>

Friendly helper method for calling the get method from the implementation of DeclEngineGet for DeclEngine

Calling [DeclEngine][get] directly is equivalent to this method, but this method adds additional syntax that some users may find helpful.

pub fn pretty_print(&self, engines: &Engines) -> String

Pretty print method for printing the DeclEngine. This method is manually implemented to avoid implementation overhead regarding using [DisplayWithEngines].

pub fn metrics(&self) -> DeclEngineMetrics